# API Reference

This is the code documentation for the `humlpy` package, which implements the
methodology from:

> Göbler, K., Drton, M., Mukherjee, S. and Miloschewski, A. (2024).
> **High-dimensional undirected graphical models for arbitrary mixed data.**
> *Electronic Journal of Statistics*, 18(1), 2339–2404.
> <https://doi.org/10.1214/24-EJS2254>

## Main Classes

:::humlpy.estimation.SampleCorrelation

:::humlpy.estimation.MixedGraphicalLasso

## Model Selection

:::humlpy.estimation.omega_select

## Graph Classes

:::humlpy.graphs.UGRAPH

## Correlation Functions

:::humlpy.correlation.PolychoricCorrelation

:::humlpy.correlation.PolyserialCorrelation

:::humlpy.correlation.spearman

:::humlpy.correlation.f_hat

:::humlpy.correlation.npn_pearson

:::humlpy.correlation.adhoc_polyserial

## Legacy Functions

:::humlpy.estimation.mixed_graph_nonpara

:::humlpy.estimation.mixed_graph_gauss

:::humlpy.estimation.MixedGraphResult

:::humlpy.estimation.edgenumber
